Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7)

Unified Diff: include/gpu/GrDistanceFieldTextContext.h

Issue 41213003: Hook in rough distance field support for fonts (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gyp/gpu.gypi ('k') | src/core/SkDraw.cpp » ('j') | src/core/SkDraw.cpp » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrDistanceFieldTextContext.h
diff --git a/include/gpu/GrBitmapTextContext.h b/include/gpu/GrDistanceFieldTextContext.h
similarity index 66%
copy from include/gpu/GrBitmapTextContext.h
copy to include/gpu/GrDistanceFieldTextContext.h
index 89672a84d5d13ac073fd72590d8421a18a86fc03..cce77d39c31859462ff312536f1d35b77e27eb0b 100755
--- a/include/gpu/GrBitmapTextContext.h
+++ b/include/gpu/GrDistanceFieldTextContext.h
@@ -5,27 +5,27 @@
* found in the LICENSE file.
*/
-#ifndef GrBitmapTextContext_DEFINED
-#define GrBitmapTextContext_DEFINED
+#ifndef GrDistanceFieldTextContext_DEFINED
+#define GrDistanceFieldTextContext_DEFINED
#include "GrTextContext.h"
class GrTextStrike;
/*
* This class implements GrTextContext using standard bitmap fonts
*/
-class GrBitmapTextContext : public GrTextContext {
+class GrDistanceFieldTextContext : public GrTextContext {
public:
- GrBitmapTextContext(GrContext*, const GrPaint&);
- virtual ~GrBitmapTextContext();
+ GrDistanceFieldTextContext(GrContext*, const GrPaint&, SkScalar textSize);
+ virtual ~GrDistanceFieldTextContext();
virtual void drawPackedGlyph(GrGlyph::PackedID, GrFixed left, GrFixed top,
GrFontScaler*) SK_OVERRIDE;
private:
- GrContext::AutoMatrix fAutoMatrix;
- GrTextStrike* fStrike;
+ GrTextStrike* fStrike;
+ SkScalar fTextSize;
void flushGlyphs(); // automatically called by destructor
« no previous file with comments | « gyp/gpu.gypi ('k') | src/core/SkDraw.cpp » ('j') | src/core/SkDraw.cpp » ('J')
@@ -5,27 +5,27 @@
class GrTextStrike;
/*
- * This class implements GrTextContext using standard bitmap fonts
+ * This class implements GrTextContext using standard DistanceField fonts
*/

Powered by Google App Engine
This is Rietveld 408576698